﻿using ASPSQLEF.Models;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using System.Data;
using System.Diagnostics;
using System.Linq;

//====================================================
// Описание работы классов и методов исходника на:
// https://www.interestprograms.ru
// Исходные коды программ и игр
// Автор исходных кодов Клочков Павел
//====================================================

namespace ASPSQLEF.Controllers
{
    public class HomeController : Controller
    {
        private readonly SqlDBContext _dBContext;

        public HomeController()
        {
            _dBContext = new SqlDBContext();
        }

        public IActionResult Index()
        {
            return View();
        }


        #region SQL запросы через интерфейс Entity Framework Core

        public IActionResult EntityFrameworkCore()
        {
            ViewBag.SubSections = _dBContext.SubSections.ToList();
            ViewBag.Sections = _dBContext.Sections.ToList();
            ViewBag.Sciences = _dBContext.Sciences.ToList();

            return View();
        }


        // Постепенно упрощаются конструкции и мощная asp.net становится ближе к народу
        [Route("science-{uri}")]
        public IActionResult Science(string uri)
        {
            Science science = _dBContext.Sciences.Where(sc => sc.Uri == uri).Include(sc => sc.Sections).ThenInclude(sec => sec.SubSections).FirstOrDefault();


            science.NumberViews++;
            _dBContext.SaveChanges();

            return View(science);
        }


        [Route("section-{uri}")]
        public IActionResult Section(string uri)
        {
            Section section = _dBContext.Sections.Where(sec => sec.Uri == uri).Include(sec => sec.SubSections).Include(sec => sec.Science).FirstOrDefault();

            section.NumberViews++;
            _dBContext.SaveChanges();

            return View(section);
        }


        [Route("subsection-{uri}")]
        public IActionResult SubSection(string uri)
        {
            SubSection subSection = _dBContext.SubSections.Where(ss => ss.Uri == uri).Include(ss => ss.Section.Science).FirstOrDefault();

            subSection.NumberViews++;
            _dBContext.SaveChanges();


            return View(subSection);
        }

        #endregion



        [ResponseCache(Duration = 0, Location = ResponseCacheLocation.None, NoStore = true)]
        public IActionResult Error()
        {
            return View(new ErrorViewModel { RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier });
        }


        // Надо или нет это, пока не выяснил.
        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                _dBContext.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
